#!/bin/bash
if [ -n "$_MEIPASS" ]; then
    script_dir="$_MEIPASS"
else
    script_dir="$(cd "$(dirname "$0")"; pwd)"
fi

ADB_PATH="$script_dir/adb/adb"
ERROR_MESSAGES=()
SUCCESS_MESSAGES=()
PACKAGE_VERIFIER="com.ecarx.xsfinstallverifier"

# Проверка ошибок
check_error() {
    if [ $? -ne 0 ]; then
        echo "Ошибка при выполнении команды: $1"
        ERROR_MESSAGES+=("Ошибка при выполнении команды: $1")
        ERROR_OCCURRED=true
    fi
}

# Проверка устройств ADB
"$ADB_PATH" devices
check_error "adb devices"

# Проверка root-доступа
"$ADB_PATH" root
if [ $? -ne 0 ]; then
    echo "Нет root-доступа. Некоторые команды могут не выполниться."
    ERROR_MESSAGES+=("Нет root-доступа. Некоторые команды могут не выполниться.")
    ERROR_OCCURRED=true
else
    ROOT_STATUS=$("$ADB_PATH" shell id -u)
    if [ "$ROOT_STATUS" -ne 0 ]; then
        echo "Нет root-доступа. Некоторые команды могут не выполниться."
        ERROR_MESSAGES+=("Нет root-доступа. Некоторые команды могут не выполниться.")
        ERROR_OCCURRED=true
    else
        echo "Root-доступ предоставлен."
    fi
fi

"$ADB_PATH" remount
if [ $? -ne 0 ]; then
    echo "Команда 'remount' недоступна или не найдена. Возможно, требуется root-доступ."
    ERROR_MESSAGES+=("Команда 'remount' недоступна или не найдена. Возможно, требуется root-доступ.")
    ERROR_OCCURRED=true
fi

"$ADB_PATH" shell settings put global verifier_verify_adb_installs 0
check_error "settings put global verifier_verify_adb_installs 0"

"$ADB_PATH" shell settings put global package_verifier_enable 0
check_error "settings put global package_verifier_enable 0"


# Проверка и отключение пакета
PACKAGE_PRESENT=$("$ADB_PATH" shell pm list packages | grep "$PACKAGE_VERIFIER")
if [ -n "$PACKAGE_PRESENT" ]; then
    "$ADB_PATH" shell pm disable "$PACKAGE_VERIFIER"
    if [ $? -ne 0 ]; then
        echo "Не удалось отключить пакет: $PACKAGE_VERIFIER. Он может препятствовать установке других приложений."
        ERROR_MESSAGES+=("Не удалось отключить пакет: $PACKAGE_VERIFIER. Он может препятствовать установке других приложений.")
        ERROR_OCCURRED=true
    else
        echo "Пакет $PACKAGE_VERIFIER отключен успешно."
    fi
else
    echo "Пакет $PACKAGE_VERIFIER не установлен. Нет необходимости отключать."
fi

# Ищем APK файлы в директории скрипта
apk_files=$(find "$script_dir" -maxdepth 1 -name "*.apk")


# Если APK файлы найдены, продолжаем обработку
if [ -n "$apk_files" ]; then
    for apk_file in $apk_files; do
        apk_name=$(basename "$apk_file")

        case "$apk_name" in
            "XCGallery.apk")
                "$ADB_PATH" push "$apk_file" /system/app/XCGallery/
                "$ADB_PATH" shell pm clear ecarx.gallery
                echo "Установка XCGallery.apk завершена."
                ;;
            "ZeekrCarManager.apk")
                "$ADB_PATH" install -g "$apk_file"
                echo "Установка ZeekrCarManager.apk завершена."
                ;;
            "ExteriorAudioPlayApp.apk")
                "$ADB_PATH" install -g "$apk_file"
                echo "Установка ExteriorAudioPlayApp.apk завершена."
                ;;         
            "XCMedia2.apk")
                "$ADB_PATH" install -g "$apk_file"
                echo "Установка XCMedia2.apk завершена."
                ;;
            "LightingShow.apk")
                "$ADB_PATH" install -g "$apk_file"
                echo "Установка LightingShow.apk завершена."
                ;;
            "XCDvr.apk")
                "$ADB_PATH" install -g "$apk_file"
                "$ADB_PATH" shell pm clear ecarx.camera.dvr
                echo "Установка XCDvr.apk завершена."
                ;;
            "ZeekrMediaCenter.apk")
                "$ADB_PATH" install -g "$apk_file"
                "$ADB_PATH" shell pm clear com.zeekr.mediacenter
                echo "Установка ZeekrMediaCenter.apk завершена."
                ;;
            "ZeekrKindMode.apk")
                "$ADB_PATH" install -g "$apk_file"
                "$ADB_PATH" shell pm clear com.geely.pma.bs.modes
                echo "Установка ZeekrKindMode.apk завершена."
                ;;
            "XCLauncher3.apk")
                "$ADB_PATH" install -g "$apk_file"
                "$ADB_PATH" shell pm clear ecarx.launcher3
                echo "Установка XCLauncher3.apk завершена."
                ;;
            "XCMemberCenter.apk")
                "$ADB_PATH" install -g "$apk_file"
                "$ADB_PATH" shell pm clear ecarx.membercenter
                echo "Установка XCMemberCenter.apk завершена."
                ;;
            "SystemUI.apk")
                "$ADB_PATH" push "$apk_file" /system/priv-app/SystemUI/
                "$ADB_PATH" shell pkill -TERM -f com.android.systemui
                echo "Установка SystemUI.apk завершена."
                ;;
            "EcarxBTPhone.apk")
                "$ADB_PATH" install -g "$apk_file"
                "$ADB_PATH" shell pm clear com.ecarx.btphone
                echo "Установка EcarxBTPhone.apk завершена."
                ;;
            "GeelyHvac.apk")
                "$ADB_PATH" install -g "$apk_file"
                "$ADB_PATH" shell pm clear com.geely.pma.climate
                echo "Установка GeelyHvac.apk завершена."
                ;;
            "GeelySettings.apk")
                "$ADB_PATH" install -g "$apk_file"
                "$ADB_PATH" shell pm clear com.geely.pma.settings
                echo "Установка GeelySettings.apk завершена."
                ;;
            "NotificationApp.apk")
                "$ADB_PATH" push "$apk_file" /system/app/NotificationApp/
                echo "Установка NotificationApp.apk завершена."
                ;;
            "XCMyCar.apk")
                "$ADB_PATH" install -g "$apk_file"
                "$ADB_PATH" shell pm clear com.ecarx.mycar
                echo "Установка XCMyCar.apk завершена."
                ;;
            "XSFNotificationCenter.apk")
                "$ADB_PATH" install -g "$apk_file"
                "$ADB_PATH" shell pm clear ecarx.xsf.notificationcenter
                echo "Установка XSFNotificationCenter.apk завершена."
                ;;
            "SentryMode.apk")
                "$ADB_PATH" install -g "$apk_file"
                "$ADB_PATH" shell pm clear zeekr.bx.sentry
                echo "Установка SentryMode.apk завершена."
                ;;
            "ZeekrCarLauncher3D.apk")
                "$ADB_PATH" install -g "$apk_file"
                "$ADB_PATH" shell pm clear com.zeekr.carlauncher3d
                echo "Установка ZeekrCarLauncher3D.apk завершена."
                ;;
            *)
                # Просто пропускаем файлы, которые не подходят
                ;;
        esac
    done
else
    echo "APK файлы не найдены в директории скрипта."
fi

# Завершаем работу adb сервера
"$ADB_PATH" kill-server
check_error "adb kill-server"

# Отображаем ошибки, если они есть
if [ "$ERROR_OCCURRED" = true ]; then
    echo "Команды не выполнены по следующим причинам:"
    for ERROR_MESSAGE in "${ERROR_MESSAGES[@]}"; do
        echo "- $ERROR_MESSAGE"
    done
    echo "Вы не сможете установить часть приложений с сайта https://zeekrinfohub.ru/"
else
    echo "Операция завершена успешно."
fi

exit 0
